@@ -96,12 +96,12 @@ tie %Config, 'Config', {
     inc_version_list => ' ',
     intsize => '4',
     ldlibpthname => 'LD_LIBRARY_PATH',
-    libpth => '/usr/local/lib /usr/lib /usr/lib/db5.3',
+    libpth => '/usr/lib /usr/lib/clang/20/lib /usr/lib/clang/20',
     osname => 'linux',
-    osvers => '5.12.15-arch1-1',
+    osvers => '6.10.11+bpo-cloud-amd64',
     path_sep => ':',
     privlibexp => '/usr/share/perl5/core_perl',
-    scriptdir => '/usr/bin/core_perl',
+    scriptdir => '/usr/bin',
     sitearchexp => '/usr/lib/perl5/5.42/site_perl',
     sitelibexp => '/usr/share/perl5/site_perl',
     so => 'so',
